@@ -294,6 +294,13 @@ static enum state_wanted detect_devices (void)
 
 static enum state_wanted get_networktype (void)
 {
+	/* Check if there is anything to activate */
+	if ((di_tree_size (channels) == 0) &&
+	    (di_tree_size (devices) == 0)) {
+		syslog (LOG_ERR, "No qeth/ctc network devices found, skipping s390-netdevice.");
+		return WANT_FINISH;
+	}
+
 	char *ptr;
 	int ret = my_debconf_input ("critical", TEMPLATE_PREFIX "choose_networktype", &ptr);
 
@@ -512,7 +519,7 @@ static enum state_wanted get_qeth_layer2 (void)
 static enum state_wanted get_qeth_port (void)
 {
 	char *ptr;
-	int ret = my_debconf_input ("critical", TEMPLATE_PREFIX "qeth/port", &ptr);
+	int ret = my_debconf_input ("medium", TEMPLATE_PREFIX "qeth/port", &ptr);
 
 	if (ret == 30)
 		return WANT_BACKUP;
